@@ -6,7 +6,7 @@ test_that("as.location returns correct class", {
   url <- "https://raw.githubusercontent.com/glynnbird/usstatesgeojson/master/california.geojson"
   b <- as.location(url)
   
-  expect_is(b, "location")
+  expect_is(b, "location_")
   expect_is(b[[1]], "character")
   expect_null(names(b))
 })
@@ -16,7 +16,7 @@ test_that("as.location print method works as expected", {
   
   url <- "https://raw.githubusercontent.com/glynnbird/usstatesgeojson/master/california.geojson"
   b <- as.location(url)
-  txt <- capture.output(print.location(b))
+  txt <- capture.output(print.location_(b))
   
   expect_is(txt, "character")
   expect_equal(length(txt), 3)
